@@ -24,20 +24,11 @@ fi
 
 PWD=`pwd`
 
-SYNC=0
-if [ x$1 = x--sync ]; then
-  SYNC=1
-  shift
-fi
-if [ x$1 != x ]; then
-  cd $1 || exit 1
-fi
-
-echo "Checking symlinked _igraph.so in ${ROOT_FOLDER}/igraph..."
-if [ ! -e ${ROOT_FOLDER}/igraph/_igraph.so -o ! -L ${ROOT_FOLDER}/igraph/_igraph.so ]; then
-	rm -f ${ROOT_FOLDER}/igraph/_igraph.so
-	cd ${ROOT_FOLDER}/igraph
-	ln -s ../build/lib*/igraph/_igraph.so .
+echo "Checking symlinked _igraph.so in ${ROOT_FOLDER}/src/igraph..."
+if [ ! -e ${ROOT_FOLDER}/src/igraph/_igraph.so -o ! -L ${ROOT_FOLDER}/src/igraph/_igraph.so ]; then
+	rm -f ${ROOT_FOLDER}/src/igraph/_igraph.so
+	cd ${ROOT_FOLDER}/src/igraph
+	ln -s ../../build/lib*/igraph/_igraph.so .
 	cd ${ROOT_FOLDER}
 fi
 
@@ -45,21 +36,14 @@ echo "Removing existing documentation..."
 rm -rf html
 
 echo "Generating HTML documentation..."
-${EPYDOC} --html -v -o ${DOC_API_FOLDER}/html --config ${CONFIG}
+PYTHONPATH=src ${EPYDOC} --html -v -o ${DOC_API_FOLDER}/html --config ${CONFIG}
 
 PDF=0
 which latex >/dev/null && PDF=1
 
 if [ $PDF -eq 1 ]; then
   echo "Generating PDF documentation..."
-${EPYDOC} --pdf -v -o ${DOC_API_FOLDER}/pdf --config ${CONFIG}
-fi
-
-if [ $SYNC -eq 1 ]; then
-  echo "Syncing documentation to web"
-  cp ${DOC_API_FOLDER}/pdf/igraph.pdf ${DOC_API_FOLDER}/html
-  rsync --delete -avz ${DOC_API_FOLDER}/html/ csardi@igraph.org:2222:www/doc/python/
-  rm ${DOC_API_FOLDER}/html/igraph.pdf
+  PYTHONPATH=src ${EPYDOC} --pdf -v -o ${DOC_API_FOLDER}/pdf --config ${CONFIG}
 fi
 
 cd "$PWD"
