@@ -55,6 +55,7 @@ int igraphmodule_Graph_clear(igraphmodule_GraphObject *self);
 int igraphmodule_Graph_traverse(igraphmodule_GraphObject *self, visitproc visit, void *arg);
 void igraphmodule_Graph_dealloc(igraphmodule_GraphObject* self);
 int igraphmodule_Graph_init(igraphmodule_GraphObject *self, PyObject *args, PyObject *kwds);
+PyObject* igraphmodule_Graph_subclass_from_igraph_t(PyTypeObject* type, igraph_t *graph);
 PyObject* igraphmodule_Graph_from_igraph_t(igraph_t *graph);
 PyObject* igraphmodule_Graph_str(igraphmodule_GraphObject *self);
 
@@ -186,13 +187,11 @@ PyObject* igraphmodule_Graph_edge_attributes(igraphmodule_GraphObject* self);
 PyObject* igraphmodule_Graph_get_vertices(igraphmodule_GraphObject* self, void* closure);
 PyObject* igraphmodule_Graph_get_edges(igraphmodule_GraphObject* self, void* closure);
 
-PyObject* igraphmodule_Graph_complementer(igraphmodule_GraphObject* self, PyObject* args);
+PyObject* igraphmodule_Graph_complementer(igraphmodule_GraphObject* self, PyObject* args, PyObject* kwds);
 PyObject* igraphmodule_Graph_complementer_op(igraphmodule_GraphObject* self);
 PyObject* igraphmodule_Graph_compose(igraphmodule_GraphObject* self, PyObject* other);
 PyObject* igraphmodule_Graph_difference(igraphmodule_GraphObject* self, PyObject* other);
 PyObject* igraphmodule_Graph_disjoint_union(igraphmodule_GraphObject* self, PyObject* other);
-PyObject* igraphmodule_Graph_intersection(igraphmodule_GraphObject* self, PyObject* other);
-PyObject* igraphmodule_Graph_union(igraphmodule_GraphObject* self, PyObject* other);
 
 PyObject* igraphmodule_Graph_bfs(igraphmodule_GraphObject* self, PyObject* args, PyObject* kwds);
 PyObject* igraphmodule_Graph_bfsiter(igraphmodule_GraphObject* self, PyObject* args, PyObject* kwds);
